<?php

namespace App\Api;

use App\Model\TacticModel;

use App\HttpCodes;

/**
 * API endpoint related to tactics
 */
class TacticEndpoint {
    private TacticModel $model;

    /**
     * @param TacticModel $model
     */
    public function __construct(TacticModel $model) {
        $this->model = $model;
    }


    public function updateName(int $tactic_id): void {
        $request_body = file_get_contents('php://input');
        $data = json_decode($request_body);

        if (!isset($data->name)) {
            http_response_code(HttpCodes::BAD_REQUEST);
            echo "missing 'name'";
            return;
        }

        $fails = [];

        $this->model->updateName($fails, $tactic_id, $data->name);
        if (!empty($fails)) {
            http_response_code(HttpCodes::PRECONDITION_FAILED);
            echo json_encode($fails);
        }
    }

    public function newTactic(): void {
        $request_body = file_get_contents('php://input');
        $data = json_decode($request_body);

        $initial_name = $data->name;

        if (!isset($data->name)) {
            http_response_code(HttpCodes::BAD_REQUEST);
            echo "missing 'name'";
            return;
        }

        $fails = [];
        $tactic = $this->model->makeNew($fails, $initial_name);

        if (!empty($fails)) {
            http_response_code(HttpCodes::PRECONDITION_FAILED);
            echo json_encode($fails);
            return;
        }

        $id = $tactic->getId();
        echo "{id: $id}";
    }

    public function getTacticInfo(int $id): void {
        $tactic_info = $this->model->get($id);

        if ($tactic_info == null) {
            http_response_code(HttpCodes::NOT_FOUND);
            return;
        }

        echo json_encode($tactic_info);
    }

}