<?php

namespace App\Model;

use App\Data\TacticInfo;
use App\Gateway\TacticInfoGateway;
use App\Validation\ValidationFail;
use App\Validation\Validation;
use App\Validation\Validators;

class TacticModel {

    public const TACTIC_DEFAULT_NAME = "Nouvelle tactique";


    private TacticInfoGateway $tactics;

    /**
     * @param TacticInfoGateway $tactics
     */
    public function __construct(TacticInfoGateway $tactics) {
        $this->tactics = $tactics;
    }

    public function makeNew(array &$fails, string $name): ?TacticInfo {
        $failure = Validation::validate($name, "name", $fails, Validators::nonEmpty(), Validators::noInvalidChars());
        if ($failure) {
            return null;
        }
        $this->tactics->insert($name);
    }

    public function makeNewDefault(): ?TacticInfo {
        return $this->tactics->insert(self::TACTIC_DEFAULT_NAME);
    }

    /**
     * Tries to retrieve information about a tactic
     * @param int $id tactic identifier
     * @return TacticInfo|null or null if the identifier did not match a tactic
     */
    public function get(int $id): ?TacticInfo {
        return $this->tactics->get($id);
    }

    /**
     * Update the name of a tactic
     * @param int $id the tactic identifier
     * @param string $name the new name to set
     */
    public function updateName(array &$fails, int $id, string $name): void {
        $failure = Validation::validate($name, "name", $fails, Validators::nonEmpty(), Validators::noInvalidChars());

        if ($this->tactics->get($id) == null) {
            $fails[] = ValidationFail::notFound("$id is an unknown tactic identifier");
        } else if (!$failure) {
            $this->tactics->updateName($id, $name);
        }
    }

}