<?php

namespace App\Validation;

/**
 * A simple validator that takes a predicate and an error factory
 */
class SimpleFunctionValidator implements Validator {

    private $predicate;
    private $error_factory;

    /**
     * @param callable $predicate a function predicate with signature: `(string) => bool`, to validate the given string
     * @param callable $error_factory a factory function with signature `(string) => Error)` to emit error when the predicate fails
     */
    public function __construct(callable $predicate, callable $error_factory) {
        $this->predicate = $predicate;
        $this->error_factory = $error_factory;
    }

    public function validate(string $name, $val): ?ValidationFail {
        if (!call_user_func_array($this->predicate, [$val])) {
            return call_user_func_array($this->error_factory, [$name]);
        }
        return null;
    }
}