<?php

namespace App\Validation;

/**
 * Utility class for validation
 */
class Validation {

    /**
     * Validate a value from validators, appending failures in the given errors array.
     * @param mixed $val the value to validate
     * @param string $val_name the name of the value
     * @param array $errors array to push when a validator fails
     * @param Validator ...$validators given validators
     * @return bool true if any of the given validators did fail
     */
    public static function validate($val, string $val_name, array &$errors, Validator...$validators): bool {
        $had_errors = false;
        foreach ($validators as $validator) {
            $error = $validator->validate($val_name, $val);
            if ($error != null) {
                $errors[] = $error;
                $had_errors = true;
            }
        }
        return $had_errors;
    }

}